@@ -11,7 +11,10 @@ def main():
     """
     Run pylint on some code with the cmt.bmi.checker plugin loaded.
     """
-    args = sys.argv[1:] + ['--load-plugins=cmt.bmi.checker']
+    args = ['--load-plugins=cmt.bmi.checker',
+            '--disable=all',
+            '--enable=bmi,E0222,W0221',
+           ] + sys.argv[1:] 
     Run(args)
 
 if __name__ == '__main__':
